@@ -3,11 +3,11 @@ print.CA3variants <-function(x, digits=3,...) {
     print(x$iteration)
     cat("\n    RESULTS for 3-way Correspondence Analysis\n")
         if ((x$ca3type=="CA3")|(x$ca3type=="OCA3")){
-        cat("Three-way Pearson ratio table \n")
+        cat("Three-way Pearson standardised residuals \n")
         print(round(x$xs, digits = 2))
     } 
 else {
-        cat("Three-way centered column profile table \n")
+        cat("Three-way (weighted) centered column profile table \n")
         print(round(x$xs, digits = 2))
     }
 cat("\n Row marginals\n\n")
@@ -18,20 +18,20 @@ cat("\n Tube marginals\n\n")
      print(round(apply(x$DataMatrix/sum(x$DataMatrix), 3, sum), digits = digits))
     cat("Reconstruction of Data array by components and core array \n")
     print(round(x$xhat, digits = digits))
-    cat("Explained inertia ", x$nxhat2, "\n\n")
-    cat("Total inertia ", x$inertia, "\n\n")
-    cat("Percent inertia  \n\n")
-    print(round(x$inertiapc,digits=digits))
-cat("The percentage contribution of the three components to the total variation\n\n")
-    print(round(x$inertiapc,digits=digits))
-cat("The vector of the percentage contributions of the interactively coded colum-tube  components to the total inertia, 
+    cat("Explained inertia (reduced dimensions)", x$inertiatot, "\n\n")
+    cat("Total inertia (complete dimensions)", x$inertiaorig, "\n\n")
+#    cat("Percentage of explained inertia on total inertia  \n\n")
+ cat("The percentage contribution of the three components to the total variation\n\n")
+   print(round(x$inertiapcsum,digits=digits))
+#   print(round(x$inertiapc,digits=digits))
+cat("The vector of the percentage contributions of the interactively coded colum-tube components to the total inertia, 
 useful for making interactively coded biplots\n\n")
     print(round(x$inertiacoltub,digits=digits))
-cat("The vector of the percentage contributions of the row  components to the total inertia, 
+cat("The vector of the percentage contributions of the row components to the total inertia, 
 useful for making response biplots\n\n")
     print(round(x$inertiarow,digits=digits))
-    cat("Proportion of explained inertia (when reducing dimensions)\n\n")
-    print(x$prp)
+    #cat("Proportion of explained inertia (when reducing dimensions)\n\n")
+    #print(x$prp)
     cat("\n Rows in principal coordinates\n\n")
     print(round(x$fi), digits = digits)
     cat("\n Rows in standard coordinates\n\n")
@@ -47,4 +47,4 @@ useful for making response biplots\n\n")
     cat("\n Index partionings\n\n")
     print(round(x$index3,digits=digits))
     cat("\n\n")
-}
+}
\ No newline at end of file
